{% extends "name/base.html" %}
{% load staticfiles %}
{% load humanize %}

{% block title %}Statistics{% endblock %}
{% block head-extra %}
<script type="text/javascript" src="https://www.google.com/jsapi"></script>
{% endblock %}

{% block content %}
    <div class="row">
        <div class="col-sm-12">
            <div class="jumbotron">
                <div class="text-center">
                    <h3>There are {{ total_names|intcomma }} total names in {{ name_app_title }}.  There are {{ total_identifiers|intcomma }} total links attached to Name records.</h3></div>
            </div>
        </div>
    </div>
    <div class="row">
        <div class="col-sm-12">
            <div class="text-center" id="dashboard">
                <form action="{% url "name:stats-json" %}"></form>
                <div class="btn-group">
                    <button class="btn btn-primary chart-nav" id="b0" data-chart-id="0">Names Created per Month</button>
                    <button class="btn btn-primary chart-nav" id="b1" data-chart-id="1">Running Created Names Total</button>
                    <button class="btn btn-primary chart-nav" id="b2" data-chart-id="2">Names Edited per Month</button>
                    <button class="btn btn-primary chart-nav" id="b3" data-chart-id="3">Running Edited Names Total</button>
                </div>
                <div class="hidden-xs hidden-sm" id="chart"></div>
                <div class="hidden-xs hidden-sm"id="control"></div>
                <div id="piechart"></div>
            </div>
        </div>
    </div>
    <script type="text/javascript" src="{% static "name/js/stats.js" %}"></script>
{% endblock %}
