{% load staticfiles %}
<!DOCTYPE html PUBLIC "-//W3C//DTD HTML 4.01//EN"
   "http://www.w3.org/TR/html4/strict.dtd">

<html lang="en">

<head>
    <meta http-equiv="Content-Type" content="text/html; charset=utf-8">
    <title>{% block title %}{% endblock %}</title>
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <link rel="search" type="application/opensearchdescription+xml" title="{{ name_app_title }} Search" href="{% url "name:opensearch" %}">
    <link rel="icon" type="image/png" href="{% static "name/img/favicon.png" %}">

    <link rel="stylesheet" href="{% static 'name/css/name.css' %}">
    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/font-awesome/4.3.0/css/font-awesome.min.css">

    <link rel="stylesheet" href="//maxcdn.bootstrapcdn.com/bootswatch/3.3.4/paper/bootstrap.min.css">
    <link rel="stylesheet" href="http://code.jquery.com/ui/1.9.2/themes/base/jquery-ui.css" type="text/css" media="all">

    <script type="text/javascript" src="http://code.jquery.com/jquery-latest.js"></script>
    <script src="http://code.jquery.com/ui/1.9.2/jquery-ui.js" type="text/javascript"></script>
    <script src="https://maxcdn.bootstrapcdn.com/bootstrap/3.3.4/js/bootstrap.min.js"></script>

    <script type="text/javascript" src="{% static "name/js/ajax-form.js" %}"></script>

    {%  block head-extra %}{% endblock %}
</head>
<body>
    {% include "name/_navbar.html" %}
    <div id="body">
        {% block body %}
            <div class="content_title">
                {% block content_title %}{% endblock content_title %}
            </div>

            <div class="container">
                {% block content %}{% endblock content %}
            </div>
        {% endblock body %}
    </div>
</body>
</html>
